#[non_exhaustive]pub struct AuthMaterialBuilder { /* private fields */ }Expand description
A builder for AuthMaterial.
Implementations
Sourceimpl AuthMaterialBuilder
impl AuthMaterialBuilder
Sourcepub fn secrets_manager(self, input: SecretsManager) -> Self
pub fn secrets_manager(self, input: SecretsManager) -> Self
Configuration for AWS Secrets Manager, used to securely store and manage sensitive information for connector destinations.
This field is required.Sourcepub fn set_secrets_manager(self, input: Option<SecretsManager>) -> Self
pub fn set_secrets_manager(self, input: Option<SecretsManager>) -> Self
Configuration for AWS Secrets Manager, used to securely store and manage sensitive information for connector destinations.
Sourcepub fn get_secrets_manager(&self) -> &Option<SecretsManager>
pub fn get_secrets_manager(&self) -> &Option<SecretsManager>
Configuration for AWS Secrets Manager, used to securely store and manage sensitive information for connector destinations.
Sourcepub fn auth_material_name(self, input: impl Into<String>) -> Self
pub fn auth_material_name(self, input: impl Into<String>) -> Self
The name of the authorization material.
This field is required.Sourcepub fn set_auth_material_name(self, input: Option<String>) -> Self
pub fn set_auth_material_name(self, input: Option<String>) -> Self
The name of the authorization material.
Sourcepub fn get_auth_material_name(&self) -> &Option<String>
pub fn get_auth_material_name(&self) -> &Option<String>
The name of the authorization material.
Sourcepub fn build(self) -> Result<AuthMaterial, BuildError>
pub fn build(self) -> Result<AuthMaterial, BuildError>
Consumes the builder and constructs a AuthMaterial.
This method will fail if any of the following fields are not set: