#[non_exhaustive]pub struct WiFiSimpleSetupConfigurationBuilder { /* private fields */ }Expand description
A builder for WiFiSimpleSetupConfiguration.
Implementations
Sourceimpl WiFiSimpleSetupConfigurationBuilder
impl WiFiSimpleSetupConfigurationBuilder
Sourcepub fn enable_as_provisioner(self, input: bool) -> Self
pub fn enable_as_provisioner(self, input: bool) -> Self
Indicates whether the device can act as a provisioner in Wi-Fi Simple Setup, allowing it to configure other devices.
Sourcepub fn set_enable_as_provisioner(self, input: Option<bool>) -> Self
pub fn set_enable_as_provisioner(self, input: Option<bool>) -> Self
Indicates whether the device can act as a provisioner in Wi-Fi Simple Setup, allowing it to configure other devices.
Sourcepub fn get_enable_as_provisioner(&self) -> &Option<bool>
pub fn get_enable_as_provisioner(&self) -> &Option<bool>
Indicates whether the device can act as a provisioner in Wi-Fi Simple Setup, allowing it to configure other devices.
Sourcepub fn enable_as_provisionee(self, input: bool) -> Self
pub fn enable_as_provisionee(self, input: bool) -> Self
Indicates whether the device can act as a provisionee in Wi-Fi Simple Setup, allowing it to be configured by other devices.
Sourcepub fn set_enable_as_provisionee(self, input: Option<bool>) -> Self
pub fn set_enable_as_provisionee(self, input: Option<bool>) -> Self
Indicates whether the device can act as a provisionee in Wi-Fi Simple Setup, allowing it to be configured by other devices.
Sourcepub fn get_enable_as_provisionee(&self) -> &Option<bool>
pub fn get_enable_as_provisionee(&self) -> &Option<bool>
Indicates whether the device can act as a provisionee in Wi-Fi Simple Setup, allowing it to be configured by other devices.
Sourcepub fn timeout_in_minutes(self, input: i32) -> Self
pub fn timeout_in_minutes(self, input: i32) -> Self
The timeout duration in minutes for Wi-Fi Simple Setup. Valid range is 5 to 15 minutes.
Sourcepub fn set_timeout_in_minutes(self, input: Option<i32>) -> Self
pub fn set_timeout_in_minutes(self, input: Option<i32>) -> Self
The timeout duration in minutes for Wi-Fi Simple Setup. Valid range is 5 to 15 minutes.
Sourcepub fn get_timeout_in_minutes(&self) -> &Option<i32>
pub fn get_timeout_in_minutes(&self) -> &Option<i32>
The timeout duration in minutes for Wi-Fi Simple Setup. Valid range is 5 to 15 minutes.
Sourcepub fn build(self) -> WiFiSimpleSetupConfiguration
pub fn build(self) -> WiFiSimpleSetupConfiguration
Consumes the builder and constructs a WiFiSimpleSetupConfiguration.