#[non_exhaustive]pub struct AuthMaterial {
pub secrets_manager: Option<SecretsManager>,
pub auth_material_name: String,
}Expand description
The authorization material containing the Secrets Manager arn and version.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.secrets_manager: Option<SecretsManager>Configuration for AWS Secrets Manager, used to securely store and manage sensitive information for connector destinations.
auth_material_name: StringThe name of the authorization material.
Implementations
Sourceimpl AuthMaterial
impl AuthMaterial
Sourcepub fn secrets_manager(&self) -> Option<&SecretsManager>
pub fn secrets_manager(&self) -> Option<&SecretsManager>
Configuration for AWS Secrets Manager, used to securely store and manage sensitive information for connector destinations.
Sourcepub fn auth_material_name(&self) -> &str
pub fn auth_material_name(&self) -> &str
The name of the authorization material.
Sourceimpl AuthMaterial
impl AuthMaterial
Sourcepub fn builder() -> AuthMaterialBuilder
pub fn builder() -> AuthMaterialBuilder
Creates a new builder-style object to manufacture AuthMaterial.