#[non_exhaustive]pub struct WiFiSimpleSetupConfiguration {
pub enable_as_provisioner: Option<bool>,
pub enable_as_provisionee: Option<bool>,
pub timeout_in_minutes: Option<i32>,
}Expand description
The Wi-Fi Simple Setup configuration for the managed thing, which defines provisioning capabilities and timeout settings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_as_provisioner: Option<bool>Indicates whether the device can act as a provisioner in Wi-Fi Simple Setup, allowing it to configure other devices.
enable_as_provisionee: Option<bool>Indicates whether the device can act as a provisionee in Wi-Fi Simple Setup, allowing it to be configured by other devices.
timeout_in_minutes: Option<i32>The timeout duration in minutes for Wi-Fi Simple Setup. Valid range is 5 to 15 minutes.
Implementations
Sourceimpl WiFiSimpleSetupConfiguration
impl WiFiSimpleSetupConfiguration
Sourcepub fn enable_as_provisioner(&self) -> Option<bool>
pub fn enable_as_provisioner(&self) -> Option<bool>
Indicates whether the device can act as a provisioner in Wi-Fi Simple Setup, allowing it to configure other devices.
Sourcepub fn enable_as_provisionee(&self) -> Option<bool>
pub fn enable_as_provisionee(&self) -> Option<bool>
Indicates whether the device can act as a provisionee in Wi-Fi Simple Setup, allowing it to be configured by other devices.
Sourcepub fn timeout_in_minutes(&self) -> Option<i32>
pub fn timeout_in_minutes(&self) -> Option<i32>
The timeout duration in minutes for Wi-Fi Simple Setup. Valid range is 5 to 15 minutes.
Sourceimpl WiFiSimpleSetupConfiguration
impl WiFiSimpleSetupConfiguration
Sourcepub fn builder() -> WiFiSimpleSetupConfigurationBuilder
pub fn builder() -> WiFiSimpleSetupConfigurationBuilder
Creates a new builder-style object to manufacture WiFiSimpleSetupConfiguration.